@@ -103,11 +103,12 @@ function (x, centers = 2, iter.base = 10, minsize = 0,
 {
     d <- dist(object$allcenters, method = dist.method)
     if(hclust.method=="diana"){
-        if (!require("cluster")) stop("Could not load required package cluster")        
-        object$hclust <- as.hclust(cluster::diana(d, diss=TRUE))
+        if (system.file(package = "cluster") == "")
+            stop("Could not load required package 'cluster'!")
+        object$hclust <- stats::as.hclust(cluster::diana(d, diss=TRUE))
     }
     else
-        object$hclust <- hclust(d, method = hclust.method)
+        object$hclust <- stats::hclust(d, method = hclust.method)
     
     if(docmdscale){
         object$cmdscale <- cmdscale(d)
